<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Polyline</name>
    <message>
        <location filename="../Polyline.js" line="+73"/>
        <source>Polyline Tools</source>
        <translatorcomment>--google--
Pokaż menu &quot;Łamane&quot;</translatorcomment>
        <translation>Narzędzia linii łamanej</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show polyline tools</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Pokaż menu &quot;Łamane&quot;</translatorcomment>
        <translation>Wyświetla narzędzia linii łamanej</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Polyline</source>
        <translatorcomment>--exact match--
--file: qcadactions_pl.ts--
Linia ł&amp;amana</translatorcomment>
        <translation>Linia ł&amp;amana</translation>
    </message>
</context>
</TS>
